@@ -2,11 +2,11 @@ package k8shandler
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	configv1 "github.com/openshift/api/config/v1"
 	logging "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1"
-	logforwarding "github.com/openshift/cluster-logging-operator/pkg/apis/logging/v1alpha1"
 	"github.com/openshift/cluster-logging-operator/pkg/logger"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	client "sigs.k8s.io/controller-runtime/pkg/client"
@@ -17,80 +17,91 @@ import (
 
 func Reconcile(requestCluster *logging.ClusterLogging, requestClient client.Client) (err error) {
 	clusterLoggingRequest := ClusterLoggingRequest{
-		client:  requestClient,
-		cluster: requestCluster,
+		Client:  requestClient,
+		Cluster: requestCluster,
 	}
 
-	forwarding := clusterLoggingRequest.getLogForwarding()
-	if forwarding != nil {
-		clusterLoggingRequest.ForwardingRequest = forwarding
-		clusterLoggingRequest.ForwardingSpec = forwarding.Spec
+	forwarder := clusterLoggingRequest.getLogForwarder()
+	if forwarder != nil {
+		clusterLoggingRequest.ForwarderRequest = forwarder
+		clusterLoggingRequest.ForwarderSpec = forwarder.Spec
 	}
 
 	proxyConfig := clusterLoggingRequest.getProxyConfig()
 
 	// Reconcile certs
 	if err = clusterLoggingRequest.CreateOrUpdateCertificates(); err != nil {
-		return fmt.Errorf("Unable to create or update certificates for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update certificates for %q: %v", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	// Reconcile Log Store
 	if err = clusterLoggingRequest.CreateOrUpdateLogStore(); err != nil {
-		return fmt.Errorf("Unable to create or update logstore for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update logstore for %q: %v", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	// Reconcile Visualization
 	if err = clusterLoggingRequest.CreateOrUpdateVisualization(proxyConfig); err != nil {
-		return fmt.Errorf("Unable to create or update visualization for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update visualization for %q: %v", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	// Reconcile Curation
 	if err = clusterLoggingRequest.CreateOrUpdateCuration(); err != nil {
-		return fmt.Errorf("Unable to create or update curation for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update curation for %q: %v", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	// Reconcile Collection
 	if err = clusterLoggingRequest.CreateOrUpdateCollection(proxyConfig); err != nil {
-		return fmt.Errorf("Unable to create or update collection for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update collection for %q: %v", clusterLoggingRequest.Cluster.Name, err)
+	}
+
+	// Reconcile Metrics Dashboards
+	if err = clusterLoggingRequest.CreateOrUpdateDashboards(); err != nil {
+		return fmt.Errorf("Unable to create or update metrics dashboards for %q: %w", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	return nil
 }
 
-func ReconcileForLogForwarding(forwarding *logforwarding.LogForwarding, requestClient client.Client) (err error) {
-	logger.DebugObject("Reconciling LogForwarding instance: %v", forwarding)
+func ReconcileForClusterLogForwarder(forwarder *logging.ClusterLogForwarder, requestClient client.Client) (err error) {
+	logger.DebugObject("Reconciling ClusterLogForwarder instance: %v", forwarder)
 	clusterLoggingRequest := ClusterLoggingRequest{
-		client: requestClient,
+		Client: requestClient,
 	}
-	if forwarding != nil {
-		clusterLoggingRequest.ForwardingRequest = forwarding
-		clusterLoggingRequest.ForwardingSpec = forwarding.Spec
+	if forwarder != nil {
+		clusterLoggingRequest.ForwarderRequest = forwarder
+		clusterLoggingRequest.ForwarderSpec = forwarder.Spec
 	}
 
 	clusterLogging := clusterLoggingRequest.getClusterLogging()
 	if clusterLogging == nil {
+		logger.Debug("No clusterlogging object, cannot reconcile")
 		return nil
 	}
-	clusterLoggingRequest.cluster = clusterLogging
+	clusterLoggingRequest.Cluster = clusterLogging
 
 	if clusterLogging.Spec.ManagementState == logging.ManagementStateUnmanaged {
+		logger.Debugf("Unmanaged state, nothing to reconcile")
 		return nil
 	}
 
 	proxyConfig := clusterLoggingRequest.getProxyConfig()
 
 	// Reconcile Collection
-	if err = clusterLoggingRequest.CreateOrUpdateCollection(proxyConfig); err != nil {
-		return fmt.Errorf("Unable to reconcile collection for %q: %v", clusterLoggingRequest.cluster.Name, err)
+	err = clusterLoggingRequest.CreateOrUpdateCollection(proxyConfig)
+	forwarder.Status = clusterLoggingRequest.ForwarderRequest.Status
+	logger.DebugObject("ClusterLogForwarder status after updating collection: %#v", forwarder.Status)
+	if err != nil {
+		msg := fmt.Sprintf("Unable to reconcile collection for %q: %v", clusterLoggingRequest.Cluster.Name, err)
+		logger.Errorf(msg)
+		return errors.New(msg)
 	}
-
 	return nil
 }
 
 func ReconcileForGlobalProxy(proxyConfig *configv1.Proxy, requestClient client.Client) (err error) {
 
 	clusterLoggingRequest := ClusterLoggingRequest{
-		client: requestClient,
+		Client: requestClient,
 	}
 
 	clusterLogging := clusterLoggingRequest.getClusterLogging()
@@ -98,21 +109,21 @@ func ReconcileForGlobalProxy(proxyConfig *configv1.Proxy, requestClient client.C
 		return nil
 	}
 
-	clusterLoggingRequest.cluster = clusterLogging
+	clusterLoggingRequest.Cluster = clusterLogging
 
 	if clusterLogging.Spec.ManagementState == logging.ManagementStateUnmanaged {
 		return nil
 	}
 
-	forwarding := clusterLoggingRequest.getLogForwarding()
-	if forwarding != nil {
-		clusterLoggingRequest.ForwardingRequest = forwarding
-		clusterLoggingRequest.ForwardingSpec = forwarding.Spec
+	forwarder := clusterLoggingRequest.getLogForwarder()
+	if forwarder != nil {
+		clusterLoggingRequest.ForwarderRequest = forwarder
+		clusterLoggingRequest.ForwarderSpec = forwarder.Spec
 	}
 
 	// Reconcile Collection
 	if err = clusterLoggingRequest.CreateOrUpdateCollection(proxyConfig); err != nil {
-		return fmt.Errorf("Unable to create or update collection for %q: %v", clusterLoggingRequest.cluster.Name, err)
+		return fmt.Errorf("Unable to create or update collection for %q: %v", clusterLoggingRequest.Cluster.Name, err)
 	}
 
 	return nil
@@ -120,7 +131,7 @@ func ReconcileForGlobalProxy(proxyConfig *configv1.Proxy, requestClient client.C
 
 func ReconcileForTrustedCABundle(requestName string, requestClient client.Client) (err error) {
 	clusterLoggingRequest := ClusterLoggingRequest{
-		client: requestClient,
+		Client: requestClient,
 	}
 
 	clusterLogging := clusterLoggingRequest.getClusterLogging()
@@ -128,16 +139,16 @@ func ReconcileForTrustedCABundle(requestName string, requestClient client.Client
 		return nil
 	}
 
-	clusterLoggingRequest.cluster = clusterLogging
+	clusterLoggingRequest.Cluster = clusterLogging
 
 	if clusterLogging.Spec.ManagementState == logging.ManagementStateUnmanaged {
 		return nil
 	}
 
-	forwarding := clusterLoggingRequest.getLogForwarding()
-	if forwarding != nil {
-		clusterLoggingRequest.ForwardingRequest = forwarding
-		clusterLoggingRequest.ForwardingSpec = forwarding.Spec
+	forwarder := clusterLoggingRequest.getLogForwarder()
+	if forwarder != nil {
+		clusterLoggingRequest.ForwarderRequest = forwarder
+		clusterLoggingRequest.ForwarderSpec = forwarder.Spec
 	}
 
 	proxyConfig := clusterLoggingRequest.getProxyConfig()
@@ -149,7 +160,7 @@ func (clusterRequest *ClusterLoggingRequest) getClusterLogging() *logging.Cluste
 	clusterLoggingNamespacedName := types.NamespacedName{Name: constants.SingletonName, Namespace: constants.OpenshiftNS}
 	clusterLogging := &logging.ClusterLogging{}
 
-	if err := clusterRequest.client.Get(context.TODO(), clusterLoggingNamespacedName, clusterLogging); err != nil {
+	if err := clusterRequest.Client.Get(context.TODO(), clusterLoggingNamespacedName, clusterLogging); err != nil {
 		if !apierrors.IsNotFound(err) {
 			fmt.Printf("Encountered unexpected error getting %v", clusterLoggingNamespacedName)
 		}
@@ -164,7 +175,7 @@ func (clusterRequest *ClusterLoggingRequest) getProxyConfig() *configv1.Proxy {
 	// don't blank out any proxy configured changes...
 	proxyNamespacedName := types.NamespacedName{Name: constants.ProxyName}
 	proxyConfig := &configv1.Proxy{}
-	if err := clusterRequest.client.Get(context.TODO(), proxyNamespacedName, proxyConfig); err != nil {
+	if err := clusterRequest.Client.Get(context.TODO(), proxyNamespacedName, proxyConfig); err != nil {
 		if !apierrors.IsNotFound(err) {
 			fmt.Printf("Encountered unexpected error getting %v", proxyNamespacedName)
 		}
@@ -173,15 +184,15 @@ func (clusterRequest *ClusterLoggingRequest) getProxyConfig() *configv1.Proxy {
 	return proxyConfig
 }
 
-func (clusterRequest *ClusterLoggingRequest) getLogForwarding() *logforwarding.LogForwarding {
-	logForwardingNamespacedName := types.NamespacedName{Name: constants.SingletonName, Namespace: constants.OpenshiftNS}
-	logForwarding := &logforwarding.LogForwarding{}
-	logger.Debug("logforwarding-controller fetching LF instance")
-	if err := clusterRequest.client.Get(context.TODO(), logForwardingNamespacedName, logForwarding); err != nil {
+func (clusterRequest *ClusterLoggingRequest) getLogForwarder() *logging.ClusterLogForwarder {
+	nsname := types.NamespacedName{Name: constants.SingletonName, Namespace: constants.OpenshiftNS}
+	forwarder := &logging.ClusterLogForwarder{}
+	logger.Debug("clusterlogforwarder-controller fetching LF instance")
+	if err := clusterRequest.Client.Get(context.TODO(), nsname, forwarder); err != nil {
 		if !apierrors.IsNotFound(err) {
-			fmt.Printf("Encountered unexpected error getting %v", logForwardingNamespacedName)
+			fmt.Printf("Encountered unexpected error getting %v", nsname)
 		}
 	}
 
-	return logForwarding
+	return forwarder
 }
