@@ -21,7 +21,7 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
-// CreateOrUpdateVisualization reconciles visualization component for Cluster logging
+// CreateOrUpdateVisualization reconciles visualization component for cluster logging
 func (clusterRequest *ClusterLoggingRequest) CreateOrUpdateVisualization(proxyConfig *configv1.Proxy) (err error) {
 	if clusterRequest.Cluster.Spec.Visualization == nil || clusterRequest.Cluster.Spec.Visualization.Type == "" {
 		if err = clusterRequest.removeKibana(); err != nil {
@@ -197,19 +197,15 @@ func (clusterRequest *ClusterLoggingRequest) removeOldKibana() (err error) {
 }
 
 func (clusterRequest *ClusterLoggingRequest) createOrUpdateKibanaSecret() error {
-	var secrets = map[string][]byte{}
-	_ = Synchronize(func() error {
-		secrets = map[string][]byte{
-			"ca":   utils.GetWorkingDirFileContents("ca.crt"),
-			"key":  utils.GetWorkingDirFileContents("system.logging.kibana.key"),
-			"cert": utils.GetWorkingDirFileContents("system.logging.kibana.crt"),
-		}
-		return nil
-	})
+
 	kibanaSecret := NewSecret(
 		"kibana",
 		clusterRequest.Cluster.Namespace,
-		secrets)
+		map[string][]byte{
+			"ca":   utils.GetWorkingDirFileContents("ca.crt"),
+			"key":  utils.GetWorkingDirFileContents("system.logging.kibana.key"),
+			"cert": utils.GetWorkingDirFileContents("system.logging.kibana.crt"),
+		})
 
 	utils.AddOwnerRefToObject(kibanaSecret, utils.AsOwner(clusterRequest.Cluster))
 
@@ -218,18 +214,21 @@ func (clusterRequest *ClusterLoggingRequest) createOrUpdateKibanaSecret() error
 		return err
 	}
 
-	_ = Synchronize(func() error {
-		secrets = map[string][]byte{
-			"session-secret": utils.GetWorkingDirFileContents(constants.KibanaSessionSecretName),
-			"server-key":     utils.GetWorkingDirFileContents("kibana-internal.key"),
-			"server-cert":    utils.GetWorkingDirFileContents("kibana-internal.crt"),
-		}
-		return nil
-	})
+	var sessionSecret []byte
+
+	sessionSecret = utils.GetWorkingDirFileContents("kibana-session-secret")
+	if sessionSecret == nil {
+		sessionSecret = utils.GetRandomWord(32)
+	}
+
 	proxySecret := NewSecret(
 		"kibana-proxy",
 		clusterRequest.Cluster.Namespace,
-		secrets)
+		map[string][]byte{
+			"session-secret": sessionSecret,
+			"server-key":     utils.GetWorkingDirFileContents("kibana-internal.key"),
+			"server-cert":    utils.GetWorkingDirFileContents("kibana-internal.crt"),
+		})
 
 	utils.AddOwnerRefToObject(proxySecret, utils.AsOwner(clusterRequest.Cluster))
 
@@ -414,6 +413,7 @@ func (clusterRequest *ClusterLoggingRequest) removeKibanaCR() error {
 func HasCLORef(object metav1.Object, request *ClusterLoggingRequest) bool {
 	refs := object.GetOwnerReferences()
 	for _, r := range refs {
+		r := r
 		bref := utils.AsOwner(request.Cluster)
 		if AreRefsEqual(&r, &bref) {
 			return true
@@ -423,11 +423,8 @@ func HasCLORef(object metav1.Object, request *ClusterLoggingRequest) bool {
 }
 
 func AreRefsEqual(l *metav1.OwnerReference, r *metav1.OwnerReference) bool {
-	if l.Name == r.Name &&
+	return l.Name == r.Name &&
 		l.APIVersion == r.APIVersion &&
 		l.Kind == r.Kind &&
-		*l.Controller == *r.Controller {
-		return true
-	}
-	return false
+		*l.Controller == *r.Controller
 }
