@@ -1,6 +1,7 @@
 package utils
 
 import (
+	// #nosec G501
 	"crypto/md5"
 	"encoding/hex"
 	"fmt"
@@ -29,9 +30,9 @@ const (
 
 // COMPONENT_IMAGES are thee keys are based on the "container name" + "-{image,version}"
 var COMPONENT_IMAGES = map[string]string{
-	"curator":  "CURATOR_IMAGE",
-	"fluentd":  "FLUENTD_IMAGE",
-	"promtail": "PROMTAIL_IMAGE",
+	"curator": "CURATOR_IMAGE",
+	"fluentd": "FLUENTD_IMAGE",
+	"kibana":  "KIBANA_IMAGE",
 }
 
 // GetAnnotation returns the value of an annoation for a given key and true if the key was found
@@ -56,6 +57,7 @@ func AsOwner(o *logging.ClusterLogging) metav1.OwnerReference {
 
 //CalculateMD5Hash returns a MD5 hash of the give text
 func CalculateMD5Hash(text string) (string, error) {
+	// #nosec G401
 	hasher := md5.New()
 	_, err := hasher.Write([]byte(text))
 	if err != nil {
@@ -186,6 +188,7 @@ func GetShareDir() string {
 	}
 	return shareDir
 }
+
 func GetScriptsDir() string {
 	scriptsDir := os.Getenv("SCRIPTS_DIR")
 	if scriptsDir == "" {
@@ -194,23 +197,21 @@ func GetScriptsDir() string {
 	return scriptsDir
 }
 
-func GetWorkingDir() string {
+func GetWorkingDirFileContents(filePath string) []byte {
+	return GetFileContents(GetWorkingDirFilePath(filePath))
+}
+
+func GetWorkingDirFilePath(toFile string) string {
 	workingDir := os.Getenv("WORKING_DIR")
 	if workingDir == "" {
 		workingDir = DefaultWorkingDir
 	}
-	return workingDir
-}
-func GetWorkingDirFileContents(filePath string) []byte {
-	return GetFileContents(GetWorkingDirFilePath(filePath))
-}
-func GetWorkingDirFilePath(toFile string) string {
-	return path.Join(GetWorkingDir(), toFile)
+	return path.Join(workingDir, toFile)
 }
 
 func WriteToWorkingDirFile(toFile string, value []byte) error {
 
-	if err := ioutil.WriteFile(GetWorkingDirFilePath(toFile), value, 0644); err != nil {
+	if err := ioutil.WriteFile(GetWorkingDirFilePath(toFile), value, 0600); err != nil {
 		return fmt.Errorf("Unable to write to working dir: %v", err)
 	}
 
@@ -399,12 +400,9 @@ func EnvVarSourceEqual(esource1, esource2 v1.EnvVarSource) bool {
 }
 
 func EnvVarResourceFieldSelectorEqual(resource1, resource2 v1.ResourceFieldSelector) bool {
-	if (resource1.ContainerName == resource2.ContainerName) &&
-		(resource1.Resource == resource2.Resource) &&
-		(resource1.Divisor.Cmp(resource2.Divisor) == 0) {
-		return true
-	}
-	return false
+	return resource1.ContainerName == resource2.ContainerName &&
+		resource1.Resource == resource2.Resource &&
+		resource1.Divisor.Cmp(resource2.Divisor) == 0
 }
 
 func SetProxyEnvVars(proxyConfig *configv1.Proxy) []v1.EnvVar {
